\name{pava.functions}
\alias{pava.functions}
\alias{pava.simple.order}
\alias{pava.simple.tree}
\alias{pava.umbrella}



\title{ Apply PAVA Order Constraints }
\description{ Implements a Pool Adjacent Violators Algorithm (PAVA). }
\usage{
pava.simple.order(theta, cov.theta=diag(length(theta)) , node = NULL,
                  decreasing = FALSE)
pava.simple.tree(theta, cov.theta=diag(length(theta)), node = 1,
                 decreasing = FALSE )
pava.umbrella(theta, cov.theta=diag(length(theta)), node = 1, 
              decreasing = FALSE )
}

\arguments{
  \item{theta}{ \eqn{p_1 \times 1}{p1 x 1} vector on which to apply PAVA order constraints.}
  \item{cov.theta}{ \eqn{p_1 \times 1}{p1 x 1} covariance matrix of theta. }
  \item{node}{ node element. Set to \code{NULL} for simple order. }
  \item{decreasing}{ logical indicating whether the initial order constraint is increasing or decreasing.}
}

\details{
Refer to \code{\link{create.constraints}} or \code{\link{constrained.lme}} for more information on arguments \code{node} and \code{decreasing}.
}

\value{
The function returns a \eqn{p_1 \times 1}{p1 x 1} vector of order-restricted estimates of \code{theta}.
}

\references{

Farnan, L., Ivanova, A., and Peddada, S. D. (2014).
  Linear Mixed Efects Models under Inequality Constraints with Applications.
  \emph{PLOS ONE}, 9(1). e84778. doi: 10.1371/journal.pone.0084778
  \url{http://www.plosone.org/article/info:doi/10.1371/journal.pone.0084778}

}

\author{ Author:  Casey M. Jelsema <casey.jelsema@nih.gov> }

\note{
Custom PAVA algorithms (supplied to other functions such as \code{\link{constrained.lme}} or \code{\link{clme.em}} as the argument \code{pava.algorithm}) must take the same four arguments and produce the same output as described here. Often such functions may call the default PAVA functions in a particular way (specific to the application at hand).

To prevent errors, arguments \code{node} and \code{decreasing} (or ellipses) should be included even if they are not necessary.
}


\examples{

test.pava <- c(4,2,7,5,9)
th.cov    <- diag(length(test.pava))

pava.simple.order( theta=test.pava  , cov.theta=th.cov , node=NULL , 
  decreasing=FALSE )
pava.simple.tree(  theta=test.pava  , cov.theta=th.cov , node=3    , 
  decreasing=TRUE )
pava.umbrella(     theta=test.pava  , cov.theta=th.cov , node=2    , 
  decreasing=TRUE )

}


